@@ -263,7 +263,10 @@ class RequestQueuer(object):
 
     def _checkActive(self):
         while self.getActive() < self.max_simul_reqs and self.getPending() > 0:     
-            LOGGER.critical("CHECK ACTIVE LOOP")   
+            LOGGER.critical("Active: %s, Max Simul: %s, Pending: %s" % (
+                self.getActive(),
+                self.max_simul_reqs,
+                self.getPending()))   
             hosts = self.pending_reqs.keys()
             dispatched_requests = False
             for host in hosts:
